/************************************************************************************************************************************
*																																	*
*																																	*
*																																	*
*	PART 1: BASELINE PERIOD (2007-2011)																								*
*																																	*
*																																	*
*																																	*
************************************************************************************************************************************/

clear
clear matrix
set more off, permanently
set matsize 10000

insheet using "E:\2. Projects\3. Trade Credi Propagation\Results\creditor_debtor.csv"

/************************************************************************************************************************************
*																																	*
*	PANEL A in TABLE 1: DESCRIPTIVE STATISTICS ON FIRM-SPECIFIC VARIABLES															*
*																																	*
************************************************************************************************************************************/

tabstat tradecredit tradecredit_ap ebitta tlta1 chta tangible dta1 dts1 ts_ta antanst1 age1 ucr fou_oms findep dum_findep liqcon konk1 beloppta_timing beloppar, stat(mean median sd p10 p90 n)  
tabstat tradecredit tradecredit_ap ebitta tlta1 chta tangible dta1 dts1 ts_ta antanst1 age1 ucr fou_oms findep dum_findep liqcon konk1 beloppta_timing beloppar if am43_timing==1, stat(mean median sd n)  
tabstat tradecredit tradecredit_ap ebitta tlta1 chta tangible dta1 dts1 ts_ta antanst1 age1 ucr fou_oms findep dum_findep liqcon konk1 beloppta_timing beloppar if am43_timing==0, stat(mean median sd n)  

ttest tradecredit, by(am43)
ttest tradecredit_ap, by(am43)
ttest ebitta, by(am43)
ttest tlta1, by(am43)
ttest chta, by(am43)
ttest tangible, by(am43)
ttest dta, by(am43)
ttest dts, by(am43)
ttest ts_ta, by(am43)
ttest antanst1, by(am43)
ttest age1, by(am43)
ttest ucr, by(am43)
ttest fou_oms, by(am43)
ttest findep, by(am43)
ttest dum_findep, by(am43)
ttest liqcon, by(am43)
ttest konk1, by(am43)

ranksum tradecredit, by(am43)
ranksum tradecredit_ap, by(am43)
ranksum ebitta, by(am43)
ranksum tlta1, by(am43)
ranksum chta, by(am43)
ranksum tangible, by(am43)
ranksum dta, by(am43)
ranksum dts, by(am43)
ranksum ts_ta, by(am43)
ranksum antanst1, by(am43)
ranksum age1, by(am43)
ranksum ucr, by(am43)
ranksum fou_oms, by(am43)
ranksum findep, by(am43)
ranksum dum_findep, by(am43)
ranksum liqcon, by(am43)
ranksum konk1, by(am43)

/************************************************************************************************************************************
*																																	*
*	TABLE 2: CREDIT LOSSES ASSOCIATED WITH TRADE CREDIT ISSUANCE																	*
*																																	*
************************************************************************************************************************************/

/* COLUMN (I) */

tobit beloppta_h1 tradecredit c.logant##c.logant##c.logant c.tangible##c.tangible##c.tangible findep_d c.ebitta##c.ebitta##c.ebitta i.year i.br i.msa i.ucr i.age1, robust ll(0) 

/************************************************************************************************************************************
*																																	*
*	PANEL A IN TABLE 3: CREDITOR FAILURE RISK ASSOCIATED WITH DEBTOR FAILURES														*
*																																	*
************************************************************************************************************************************/

/* COLUMN (I) */

logit konk1 am43 chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
lroc, nograph
margins, dydx(am43)

/* COLUMN (II) */

reg konk1 am43 chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
test am43 chta ebitta tlta1 logta age age2

/* COLUMN (III) */

areg konk1 am43 chta ebitta tlta1 logta age age2 i.ucr, absorb(year_sni_msa) vce(cl orgnr)
test am43 chta ebitta tlta1 logta age age2

/* COLUMN (IV) */

areg konk1 am43 chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, absorb(orgnr) vce(cl orgnr)
test am43 chta ebitta tlta1 logta age age2

/* COLUMN (V) */

logit konk1 am43_r1 am43_r2 chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
lroc, nograph
margins, dydx(am43_r1 am43_r2)

/* COLUMN (VI) */

logit konk1 am43_first am43_higher chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
lroc, nograph
margins, dydx(am43_first am43_higher)

/* COLUMN (VII) */

logit konk1 am43 am43_indirect chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
lroc, nograph
margins, dydx(am43 am43_indirect)

/************************************************************************************************************************************
*																																	*
*	PANEL A IN TABLE 4: CREDITOR FAILURE RISK ASSOCIATED WITH TRADE CREDIT LOSSES													*
*																																	*
************************************************************************************************************************************/

/* COLUMN (I) */

logit konk1 beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
lroc, nograph
margins, dydx(beloppta)

/* COLUMN (II), BENCHMARK */

logit konk1 c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
lroc, nograph
margins, dydx(beloppta)

/* COLUMN (III) */

areg konk1 beloppta chta ebitta tlta1 logta age age2 i.ucr, absorb(year_sni_msa) vce(cl orgnr)
test beloppta chta ebitta tlta1 logta age age2

/* COLUMN (IV) */

areg konk1 beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, absorb(orgnr) vce(cl orgnr)
test beloppta chta ebitta tlta1 logta age age2

/* COLUMN (V) */

areg konk1 beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if debtor!=. & number==1, absorb(debtor) vce(cl debtor)
test beloppta chta ebitta tlta1 logta age age2

/************************************************************************************************************************************
*																																	*
*	PANEL A IN TABLE 5: CROSS-SECTIONAL DETERMINANTS OF CREDITOR FAILURE RISK ASSOCIATED WITH TRADE CREDIT LOSSES					*
*																																	*
************************************************************************************************************************************/

/* COLUMN (I) */

logit konk1 c.findep##c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppta) at(findep=(-0.4069985 0.4229111)) post /* 10TH AND 90TH PERCENTILE OF INDUSTRY DISTRIBUTION */
test 1._at=2._at

/* COLUMN (II) */

logit konk1 i.dum_findep##c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppta) at(dum_findep=(0 1)) post
test 1._at=2._at

/* COLUMN (III) */

logit konk1 c.liqcon##c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppta) at(liqcon=(0.0029786 0.1604801)) post /* 10TH AND 90TH PERCENTILE OF INDUSTRY DISTRIBUTION */
test 1._at=2._at

/* COLUMN (IV) */

logit konk1 c.fou_oms##c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppta) at(fou_oms=(0 0.063)) post /* 10TH AND 90TH PERCENTILE OF INDUSTRY DISTRIBUTION */
test 1._at=2._at

/* COLUMN (V) */

logit konk1 c.tlta1##c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppta) at(tlta1=(0.1422779 0.8743626)) post
test 1._at=2._at

/* COLUMN (VI) */

logit konk1 c.chta##c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppta) at(chta=(0.0016373 0.6910956)) post
test 1._at=2._at

/* COLUMN (VII) */

logit konk1 c.ebitta##c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppta) at(ebitta=(-0.139738 0.3137255)) post
test 1._at=2._at

/************************************************************************************************************************************
*																																	*
*	PANEL A IN TABLE 6: CONTROLING FOR DEBTIOR-SPECIFIC DEMAND																		*
*																																	*
************************************************************************************************************************************/

/* COLUMN (I) */

tabstat beloppta beloppts if am43==1, stat(mean)
tabstat beloppta beloppts if gr1==1, stat(mean)  
tabstat beloppta beloppts if gr2==1, stat(mean)  
tabstat beloppta beloppts if gr3==1, stat(mean)  

/* COLUMN (II) */

logit konk1 c.beloppta##c.beloppta##i.gr1 chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppta) at(gr1=(1)) post

logit konk1 c.beloppta##c.beloppta##i.gr2 chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppta) at(gr2=(1)) post

logit konk1 c.beloppta##c.beloppta##i.gr3 chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppta) at(gr3=(1)) post

/************************************************************************************************************************************
*																																	*
*	PANEL B IN TABLE 6: CONTROLING FOR DEBTIOR-SPECIFIC DEMAND																		*
*																																	*
************************************************************************************************************************************/

/* ROW 1 & 2*/

logit konk1 c.beloppta##c.beloppta c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppta beloppts)

/* ROW 3 & 4 */

logit konk1 i.dum_findep##c.beloppta##c.beloppta i.dum_findep##c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppta) at(dum_findep=(0 1)) post
test 1._at=2._at

logit konk1 i.dum_findep##c.beloppta##c.beloppta i.dum_findep##c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppts) at(dum_findep=(0 1)) post
test 1._at=2._at

/* ROW 5 & 6 */

logit konk1 c.liqcon##c.beloppta##c.beloppta c.liqcon##c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppta) at(liqcon=(0.0029786 0.1604801)) post
test 1._at=2._at

logit konk1 c.liqcon##c.beloppta##c.beloppta c.liqcon##c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppts) at(liqcon=(0.0029786 0.1604801)) post
test 1._at=2._at

/* ROW 7 & 8 */

logit konk1 c.fou_oms##c.beloppta##c.beloppta c.fou_oms##c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppta) at(fou_oms=(0 0.063)) post
test 1._at=2._at

logit konk1 c.fou_oms##c.beloppta##c.beloppta c.fou_oms##c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppts) at(fou_oms=(0 0.063)) post
test 1._at=2._at

/* ROW 9 & 10 */

logit konk1 i.fou_dum##c.beloppta##c.beloppta i.fou_dum##c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppta) at(fou_dum=(0 1)) post
test 1._at=2._at

logit konk1 i.fou_dum##c.beloppta##c.beloppta i.fou_dum##c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppts) at(fou_dum=(0 1)) post
test 1._at=2._at

/************************************************************************************************************************************
*																																	*
*	TABLE A2: ROBUSTNESS																											*
*																																	*
************************************************************************************************************************************/

/* COLUMN (I), SPLINE MODEL */

foreach x in chta ebitta tlta1 logta age {
	_pctile `x', percentile (20 40 60 80)
	scalar `x'1=r(r1)
	scalar `x'2=r(r2)
	scalar `x'3=r(r3)
	scalar `x'4=r(r4)
}

foreach x in chta ebitta tlta1 logta age {
	gen `x'_s1=max(0,`x'-`x'1)^2
	gen `x'_s2=max(0,`x'-`x'2)^2
	gen `x'_s3=max(0,`x'-`x'3)^2
	gen `x'_s4=max(0,`x'-`x'4)^2
}

areg konk1 beloppta c.chta##c.chta chta_* c.ebitta##c.ebitta ebitta_* c.tlta1##c.tlta1 tlta1_* c.logta##c.logta logta_* c.age##c.age age_* i.ucr i.year i.br i.msa if debtor!=. & number==1, absorb(debtor) vce(cl debtor)
test beloppta chta c.chta#c.chta chta_s1 chta_s2 chta_s3 chta_s4 ebitta c.ebitta#c.ebitta ebitta_s1 ebitta_s2 ebitta_s3 ebitta_s4 tlta1 c.tlta1#c.tlta1 tlta1_s1 tlta1_s2 tlta1_s3 tlta1_s4 logta c.logta#c.logta logta_s1 logta_s2 logta_s3 logta_s4 age c.age#c.age age_s1 age_s2 age_s3 age_s4

/* COLUMN (II), Z-SCORE VARIABLES */

areg konk1 beloppta chta ebitta tlta1 logta age age2 ts_ta nwc i.ucr i.year i.br i.msa if debtor!=. & number==1, absorb(debtor) vce(cl debtor)
test beloppta chta ebitta tlta1 logta age age2

/* COLUMN (V), 5-DIGIT SNI */

egen ind_msa_year = group(sni msa year) 

areg konk1 beloppta chta ebitta tlta1 logta age age2 i.ucr, absorb(ind_msa_year) vce(cl debtor)
test beloppta chta ebitta tlta1 logta age age2

/* COLUMN (VI), DEBTOR INDUSTRY FE */

areg konk1 beloppta chta ebitta tlta1 logta age age2 i.ucr i.ind_year i.msa_year if debtor!=. & number==1, absorb(sni_mod_2007_debtor_year) vce(cl debtor)
test beloppta chta ebitta tlta1 logta age age2

/* COLUMN (VII), LOW RISK CREDITORS */

areg konk1 beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if debtor!=. & number==1 & 3<=ucr, absorb(debtor) vce(cl debtor)
test beloppta chta ebitta tlta1 logta age age2

/* COLUMN (VIII), HIGHER ORDER */

areg konk1 beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if debtor!=. & number==1 & higher!=. & 1<=higher, absorb(debtor) vce(cl debtor)
test beloppta chta ebitta tlta1 logta age age2

/* COLUMN (IX), LOW RISK DEBTORS */

areg konk1 beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if debtor!=. & number==1 & ucr_debtor!=. & 3<=ucr_debtor, absorb(debtor) vce(cl debtor)
test beloppta chta ebitta tlta1 logta age age2

/* COLUMN (X), CONTROL FOR DEMAND LOSS */

areg konk1 beloppta beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if debtor!=. & number==1, absorb(debtor) vce(cl debtor)
test beloppta beloppts chta ebitta tlta1 logta age age2

/************************************************************************************************************************************
*																																	*
*	FOOTNOTES																														*
*																																	*
************************************************************************************************************************************/

/* FOOTNOTE 23 */

logit konk1 am43 chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 50<=emp, vce(cl orgnr)
margins, dydx(am43)

/* FOOTNOTE 31  */

logit konk1 c.fou_oms##c.beloppta##c.beloppta c.tangible##c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
margins, dydx(beloppta) at(fou_oms=(0 0.063)) post
test 1._at=2._at

/************************************************************************************************************************************
*																																	*
*	TABLE A2: ROBUSTNESS (CONTINUED)																								*
*																																	*
************************************************************************************************************************************/

/* COLUMN (III) */

clear
clear matrix
set more off, permanently
set matsize 10000

insheet using "E:\2. Projects\3. Trade Credi Propagation\Results\creditor_debtor_month.csv"

areg konk1 beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if debtor!=. & number==1, absorb(debtor) vce(cl debtor)
test beloppta chta ebitta tlta1 logta age age2

/* COLUMN (IV) */

clear
clear matrix
set more off, permanently
set matsize 10000

insheet using "E:\2. Projects\3. Trade Credi Propagation\Results\creditor_debtor_all.csv"

areg konk1 beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if debtor!=. & number==1, absorb(debtor) vce(cl debtor)
test beloppta chta ebitta tlta1 logta age age2

/************************************************************************************************************************************
*																																	*
*																																	*
*																																	*
*	PART 2: EXTENDED PERIOD (1992-2011)																								*
*																																	*
*																																	*
*																																	*
************************************************************************************************************************************/

clear
clear matrix
set more off, permanently
set matsize 10000

insheet using "E:\2. Projects\3. Trade Credi Propagation\Results\creditor_debtor_1992.csv"

/************************************************************************************************************************************
*																																	*
*	PANEL B in TABLE 1: DESCRIPTIVE STATISTICS ON FIRM-SPECIFIC VARIABLES															*
*																																	*
************************************************************************************************************************************/

tabstat konk1 konk1 beloppta_timing beloppar, stat(mean median sd p10 p90 n)  
tabstat konk1 konk1 beloppta_timing beloppar if am43_timing==1, stat(mean median sd n)  
tabstat konk1 konk1 if am43_timing==0, stat(mean median sd n)  

ttest konk1, by(am43)
ranksum konk1, by(am43)

/************************************************************************************************************************************
*																																	*
*	TABLE 2: CREDIT LOSSES ASSOCIATED WITH TRADE CREDIT ISSUANCE																	*
*																																	*
************************************************************************************************************************************/

/* COLUMN (II) */

tobit beloppta_h1 tradecredit c.logant##c.logant##c.logant c.tangible##c.tangible##c.tangible findep_d c.ebitta##c.ebitta##c.ebitta i.year i.br i.msa i.ucr i.age1 if 1996<=year, robust ll(0) 

/* COLUMN (III) */

tobit beloppta_h1 d1 d2 d3 d4 d5 c.logant##c.logant##c.logant c.tangible##c.tangible##c.tangible findep_d c.ebitta##c.ebitta##c.ebitta i.year i.br i.msa i.ucr i.age1 if 1996<=year, robust ll(0) 

/* COLUMN (IV) */

tobit beloppts_h1 tradecredit c.logant##c.logant##c.logant c.tangible##c.tangible##c.tangible findep_d c.ebitta##c.ebitta##c.ebitta i.year i.br i.msa i.ucr i.age1 if 1996<=year, robust ll(0) 

/* COLUMN (V) */

logit am43_h1 tradecredit c.logant##c.logant##c.logant c.tangible##c.tangible##c.tangible findep_d c.ebitta##c.ebitta##c.ebitta i.year i.br i.msa i.ucr i.age1, vce(cl orgnr)
lroc, nograph
margins, dydx(tradecredit)

/************************************************************************************************************************************
*																																	*
*	PANEL B IN TABLE 3: CREDITOR FAILURE RISK ASSOCIATED WITH DEBTOR FAILURES														*
*																																	*
************************************************************************************************************************************/

/* COLUMN (I) */

logit konk1 am43 chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
lroc, nograph
margins, dydx(am43)

/* COLUMN (II) */

reg konk1 am43 chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, vce(cl orgnr)
test am43 chta ebitta tlta1 logta age age2

/* COLUMN (III) */

areg konk1 am43 chta ebitta tlta1 logta age age2 i.ucr, absorb(year_sni_msa) vce(cl orgnr)
test am43 chta ebitta tlta1 logta age age2

/* COLUMN (IV) */

areg konk1 am43 chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa, absorb(orgnr) vce(cl orgnr)
test am43 chta ebitta tlta1 logta age age2


/************************************************************************************************************************************
*																																	*
*	PANEL B IN TABLE 4: CREDITOR FAILURE RISK ASSOCIATED WITH TRADE CREDIT LOSSES													*
*																																	*
************************************************************************************************************************************/

/* COLUMN (I) */

logit konk1 beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
lroc, nograph
margins, dydx(beloppta)

/* COLUMN (II), BENCHMARK */

logit konk1 c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
lroc, nograph
margins, dydx(beloppta)

/* COLUMN (III) */

areg konk1 beloppta chta ebitta tlta1 logta age age2 i.ucr if 1996<=year, absorb(year_sni_msa) vce(cl orgnr)
test beloppta chta ebitta tlta1 logta age age2

/* COLUMN (IV) */

areg konk1 beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, absorb(orgnr) vce(cl orgnr)
test beloppta chta ebitta tlta1 logta age age2

/************************************************************************************************************************************
*																																	*
*	PANEL B IN TABLE 5: CROSS-SECTIONAL DETERMINANTS OF CREDITOR FAILURE RISK ASSOCIATED WITH TRADE CREDIT LOSSES					*
*																																	*
************************************************************************************************************************************/

/* COLUMN (I) */

logit konk1 c.findep##c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppta) at(findep=(-0.4069985 0.4229111)) post /* 10TH AND 90TH PERCENTILE OF INDUSTRY DISTRIBUTION */
test 1._at=2._at

/* COLUMN (II) */

logit konk1 i.dum_findep##c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppta) at(dum_findep=(0 1)) post
test 1._at=2._at

/* COLUMN (III) */

logit konk1 c.liqcon##c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppta) at(liqcon=(0.0029786 0.1604801)) post /* 10TH AND 90TH PERCENTILE OF INDUSTRY DISTRIBUTION */
test 1._at=2._at

/* COLUMN (IV) */

logit konk1 c.fou_oms##c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppta) at(fou_oms=(0 0.063)) post /* 10TH AND 90TH PERCENTILE OF INDUSTRY DISTRIBUTION */
test 1._at=2._at

/* COLUMN (V) */

logit konk1 c.tlta1##c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppta) at(tlta1=(0.1422779 0.8743626)) post
test 1._at=2._at

/* COLUMN (VI) */

logit konk1 c.chta##c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppta) at(chta=(0.0016373 0.6910956)) post
test 1._at=2._at

/* COLUMN (VII) */

logit konk1 c.ebitta##c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppta) at(ebitta=(-0.139738 0.3137255)) post
test 1._at=2._at

/* COLUMN (VIII) */

logit konk1 c.gdpg##c.beloppta##c.beloppta chta ebitta tlta1 logta age age2 i.ucr i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppta) at(gdpg=(-0.014202 0.0497975)) post
test 1._at=2._at

/************************************************************************************************************************************
*																																	*
*	PANEL A IN TABLE 6: CONTROLING FOR DEBTIOR-SPECIFIC DEMAND																		*
*																																	*
************************************************************************************************************************************/

/* COLUMN (III) */

tabstat beloppta beloppts if am43==1 & 1996<=year, stat(mean)
tabstat beloppta beloppts if gr1==1 & 1996<=year, stat(mean)  
tabstat beloppta beloppts if gr2==1 & 1996<=year, stat(mean)  
tabstat beloppta beloppts if gr3==1 & 1996<=year, stat(mean)  

/* COLUMN (IV) */

logit konk1 c.beloppta##c.beloppta##i.gr1 chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppta) at(gr1=(1)) post

logit konk1 c.beloppta##c.beloppta##i.gr2 chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppta) at(gr2=(1)) post

logit konk1 c.beloppta##c.beloppta##i.gr3 chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppta) at(gr3=(1)) post

/************************************************************************************************************************************
*																																	*
*	PANEL B IN TABLE 6: CONTROLING FOR DEBTIOR-SPECIFIC DEMAND																		*
*																																	*
************************************************************************************************************************************/

/* ROW 1 & 2*/

logit konk1 c.beloppta##c.beloppta c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppta beloppts)

/* ROW 3 & 4 */

logit konk1 i.dum_findep##c.beloppta##c.beloppta i.dum_findep##c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppta) at(dum_findep=(0 1)) post
test 1._at=2._at

logit konk1 i.dum_findep##c.beloppta##c.beloppta i.dum_findep##c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppts) at(dum_findep=(0 1)) post
test 1._at=2._at

/* ROW 5 & 6 */

logit konk1 c.liqcon##c.beloppta##c.beloppta c.liqcon##c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppta) at(liqcon=(0.0029786 0.1604801)) post
test 1._at=2._at

logit konk1 c.liqcon##c.beloppta##c.beloppta c.liqcon##c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppts) at(liqcon=(0.0029786 0.1604801)) post
test 1._at=2._at

/* ROW 7 & 8 */

logit konk1 c.fou_oms##c.beloppta##c.beloppta c.fou_oms##c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppta) at(fou_oms=(0 0.063)) post
test 1._at=2._at

logit konk1 c.fou_oms##c.beloppta##c.beloppta c.fou_oms##c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppts) at(fou_oms=(0 0.063)) post
test 1._at=2._at

/* ROW 9 & 10 */

logit konk1 i.fou_dum##c.beloppta##c.beloppta i.fou_dum##c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppta) at(fou_dum=(0 1)) post
test 1._at=2._at

logit konk1 i.fou_dum##c.beloppta##c.beloppta i.fou_dum##c.beloppts##c.beloppts chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa if 1996<=year, vce(cl orgnr)
margins, dydx(beloppts) at(fou_dum=(0 1)) post
test 1._at=2._at

/************************************************************************************************************************************
*																																	*
*	INPUT TO FIGURE 4: AGGREGATE RELEVANCE																							*
*																																	*
************************************************************************************************************************************/

logit konk1 am43 chta ebitta tlta1 logta age age2 i.ucr i.year i.br i.msa
predict yhat1

gen yhat2=1/(1+exp(-(ln(yhat1/(1-yhat1))-0.6454902*am43))) /* TURN OFF TDF COMPONENT */

sort year

egen freq1 = sum(yhat1), by(year)
egen freq2 = sum(yhat2), by(year)

gen n=1
egen num = sum(n), by(year)

sort year

quietly by year:  gen dup = cond(_N==1,0,_n)

keep if dup<=1

keep num freq1 freq2

/************************************************************************************************************************************
*																																	*
*	FOOTNOTES																														*
*																																	*
************************************************************************************************************************************/

/* FOOTNOTE 32 */

areg konk1 c.fou_oms##c.beloppta chta ebitta tlta1 logta age age2 i.ucr if 1996<=year, absorb(year_sni_msa) vce(cl orgnr)

areg konk1 i.dum_findep##c.beloppta chta ebitta tlta1 logta age age2 i.ucr if 1996<=year & findep!=., absorb(year_sni_msa) vce(cl orgnr)

areg konk1 c.liqcon##c.beloppta chta ebitta tlta1 logta age age2 i.ucr if 1996<=year, absorb(year_sni_msa) vce(cl orgnr)

/************************************************************************************************************************************
*																																	*
*																																	*
*																																	*
*	PART 3: QUARTERLY FREQUENCY (2007-2011)																							*
*																																	*
*																																	*
*																																	*
************************************************************************************************************************************/

clear
clear matrix
set more off, permanently
set matsize 10000

insheet using "E:\2. Projects\3. Trade Credi Propagation\Results\creditor_debtor_quarter.csv"

/************************************************************************************************************************************
*																																	*
*	TABLE A3: FORECASTING MODELS ESTIMATED ON A QUARTERLY FREQUENCY																	*
*																																	*
************************************************************************************************************************************/

/* COLUMN (I) */

logit y0 c.beloppta##c.beloppta ebitta tlta1 logta age age2 i.ucr i.ex_dat i.br i.msa, vce(cl orgnr)
lroc, nograph
margins, dydx(beloppta)

/* COLUMN (II) */

logit y1 c.beloppta##c.beloppta ebitta tlta1 logta age age2 i.ucr i.ex_dat i.br i.msa if ex_dat<=201109, vce(cl orgnr)
lroc, nograph
margins, dydx(beloppta)

/* COLUMN (III) */

logit y2 c.beloppta##c.beloppta ebitta tlta1 logta age age2 i.ucr i.ex_dat i.br i.msa if ex_dat<=201106, vce(cl orgnr)
lroc, nograph
margins, dydx(beloppta)

/* COLUMN (IV) */

logit y3 c.beloppta##c.beloppta ebitta tlta1 logta age age2 i.ucr i.ex_dat i.br i.msa if ex_dat<=201103, vce(cl orgnr)
lroc, nograph
margins, dydx(beloppta)

/* COLUMN (V) */

logit y4 c.beloppta##c.beloppta ebitta tlta1 logta age age2 i.ucr i.ex_dat i.br i.msa if ex_dat<=201012, vce(cl orgnr)
lroc, nograph
margins, dydx(beloppta)

/* COLUMN (VI) */

logit y6 c.beloppta##c.beloppta ebitta tlta1 logta age age2 i.ucr i.ex_dat i.br i.msa if ex_dat<=201006, vce(cl orgnr)
lroc, nograph
margins, dydx(beloppta)

/* COLUMN (VII) */

logit y8 c.beloppta##c.beloppta ebitta tlta1 logta age age2 i.ucr i.ex_dat i.br i.msa if ex_dat<=200912, vce(cl orgnr)
lroc, nograph
margins, dydx(beloppta)

/************************************************************************************************************************************
*																																	*
*																																	*
*																																	*
*	THE END																															*
*																																	*
*																																	*
*																																	*
************************************************************************************************************************************/
